#front matter
rm(list=ls())
library(foreign)
library(car)
library(lme4)
library(lattice)
library(arm)
library(texreg)

#set working directory

#read data
data<-read.dta('healthImmigLONG.dta')
lp.data<-read.csv('LaxPhillipsAJPSmodified.csv')
lp.7<-subset(lp.data,subset=issue.full%in%c('bilingual','immlicense','tuition','verify','marijuanamedical','schipsixtyfull','suicide'))

###clean data###
#indicator for immigration issue
data$immig<-as.numeric(data$issue=="bilingual" | data$issue=="immlicense" | data$issue=="tuition" | data$issue=="verify")

#salience score
data$salience<-308+1372*data$immig

#create congruence measure
data$congruent<-as.numeric((data$liberalpolicy==1 & data$opinion>=50) | (data$liberalpolicy==0 & data$opinion<50))

#size of opinion majority
data$sizeMajority<-abs(data$opinion-50)

#conservative opinion majority
data$consMajority<-as.numeric(data$opinion<50)

#old variables to incorporate
data$old.scale.nyt<- -0.521374541
data$old.scale.nyt[data$issue%in%c('marijuanamedical','schip','suicide')]<- 0.03756527

#rescale continuous variables
data$Zsalience<-(data$salience-1092)/(2*679.9359)
data$Zpubideolunweighted<-rescale(data$pubideolunweighted)
data$Zgovt_ideol <-rescale(data$govt_ideol)
data$Zgov_avg<-rescale(data$gov_avg)
data$Zleg_avg <-rescale(data$leg_avg)
data$ZSquire2009 <-rescale(data$squire2009)
data$Zavg_turnout <-rescale(data$avg_turnout)
data$Zone_party_years <-rescale(data$one_party_years)
data$Zopinion<-rescale(data$opinion)
data$ZsizeMajority<-rescale(data$sizeMajority)
data$Zturnout12 <-rescale(data$turnout12)
data$Zone_party_years0914 <-rescale(data$one_party_years0914)
data$Zgovt_ideol0914 <-rescale(data$govt_ideol0914)
data$Zgov_avg0914<-rescale(data$gov_avg0914)
data$Zleg_avg0914 <-rescale(data$leg_avg0914)

#voter ideological opposition
data$voterIdeolOpp<-ifelse(data$opinion<50,data$Zpubideolunweighted,-data$Zpubideolunweighted) #If opinion is conservative, public liberalism. Else -1*liberalism.

#governmental ideological opposition
data$govIdeolOpp<-ifelse(data$opinion<50,data$Zgovt_ideol,-data$Zgovt_ideol) #if opinion is conservative, government liberalism. Else -1*liberalism.
data$govIdeolOpp0914<-ifelse(data$opinion<50,data$Zgovt_ideol0914,-data$Zgovt_ideol0914) #if opinion is conservative, government liberalism. Else -1*liberalism.

#legislative partisan opposition (L&P got this backwards)
data$legPartyOpp<-ifelse(data$opinion<50,data$Zleg_avg,-data$Zleg_avg) #if opinion is conservative, percent Democrat. Else -1*Democrat.
data$legPartyOpp0914<-ifelse(data$opinion<50,data$Zleg_avg0914,-data$Zleg_avg0914) #if opinion is conservative, percent Democrat. Else -1*Democrat.

#gubernatorial ideological opposition (L&P got this backwards)
data$govPartyOpp<-ifelse(data$opinion<50,data$Zgov_avg,-data$Zgov_avg) #if opinion is conservative, percent Democrat. Else -1*Democrat.
data$govPartyOpp0914<-ifelse(data$opinion<50,data$Zgov_avg0914,-data$Zgov_avg0914) #if opinion is conservative, percent Democrat. Else -1*Democrat.

#interest group opposition
data$igOp<-ifelse(data$opinion<50,data$powerfulig,-data$powerfulig) #if opinion is conservative, interest group liberalism. Else -1*liberalism.

###CONGRUENCE MODELS###
#Lax & Phillips 2012, Table 4, Model 6: pure replication
lp.full.table4.mod6.pure<-glmer(congruence~rescale.size.of.majority.+rescale.nyt.bypolicygroup.full.+conservative.opinion.majority+flip.EWM.against+flip.Berry.against+flip.legislative.share.dem.mean.full+flip.gov.control.mean.dem.full+rescale.prof.full.+term.limits.full+dirdem.full+courtelected.full+flip.powerful.balance.against+rescale.turnout.full.+rescale.onepartyness.full.+(rescale.size.of.majority.|ostate.full)+(rescale.size.of.majority.|issue.full),family=binomial(link='logit'),data=lp.data);summary(lp.full.table4.mod6.pure)
lp.full.table4.mod6.noterm<-glmer(congruence~rescale.size.of.majority.+rescale.nyt.bypolicygroup.full.+conservative.opinion.majority+flip.EWM.against+flip.Berry.against+flip.legislative.share.dem.mean.full+flip.gov.control.mean.dem.full+rescale.prof.full.+dirdem.full+courtelected.full+flip.powerful.balance.against+rescale.turnout.full.+rescale.onepartyness.full.+(rescale.size.of.majority.|ostate.full)+(rescale.size.of.majority.|issue.full),family=binomial(link='logit'),data=lp.data);summary(lp.full.table4.mod6.pure)
lp.full.table4.mod6.noinit<-glmer(congruence~rescale.size.of.majority.+rescale.nyt.bypolicygroup.full.+conservative.opinion.majority+flip.EWM.against+flip.Berry.against+flip.legislative.share.dem.mean.full+flip.gov.control.mean.dem.full+rescale.prof.full.+term.limits.full+courtelected.full+flip.powerful.balance.against+rescale.turnout.full.+rescale.onepartyness.full.+(rescale.size.of.majority.|ostate.full)+(rescale.size.of.majority.|issue.full),family=binomial(link='logit'),data=lp.data);summary(lp.full.table4.mod6.pure)
lp.full.table4.mod6.nocourt<-glmer(congruence~rescale.size.of.majority.+rescale.nyt.bypolicygroup.full.+conservative.opinion.majority+flip.EWM.against+flip.Berry.against+flip.legislative.share.dem.mean.full+flip.gov.control.mean.dem.full+rescale.prof.full.+term.limits.full+dirdem.full+flip.powerful.balance.against+rescale.turnout.full.+rescale.onepartyness.full.+(rescale.size.of.majority.|ostate.full)+(rescale.size.of.majority.|issue.full),family=binomial(link='logit'),data=lp.data);summary(lp.full.table4.mod6.pure)
lp.full.table4.mod6.noprof<-glmer(congruence~rescale.size.of.majority.+rescale.nyt.bypolicygroup.full.+conservative.opinion.majority+flip.EWM.against+flip.Berry.against+flip.legislative.share.dem.mean.full+flip.gov.control.mean.dem.full+term.limits.full+dirdem.full+courtelected.full+flip.powerful.balance.against+rescale.turnout.full.+rescale.onepartyness.full.+(rescale.size.of.majority.|ostate.full)+(rescale.size.of.majority.|issue.full),family=binomial(link='logit'),data=lp.data);summary(lp.full.table4.mod6.pure)


summary(lp.full.table4.mod6.pure)
summary(lp.full.table4.mod6.noterm)
summary(lp.full.table4.mod6.noinit)
summary(lp.full.table4.mod6.nocourt)
summary(lp.full.table4.mod6.noprof)



q.1<-as.numeric(predict(lp.full.table4.mod6.pure,type="response")>0.5)
mean(q.1==lp.data$congruence[lp.data$ostate.full!="NE"])
table(q.1,lp.data$congruence[lp.data$ostate.full!="NE"])

texreg(list(lp.full.table4.mod6.pure),custom.model.names=c('39 Issues 2008'),custom.coef.names=c('Intercept','Size of Opinion Majority','Salience','Conservative Opinion Majority','Voter Ideological Opposition','Govt. Ideological Opposition','Legislative Partisan Opposition','Governor Partisan Opposition','Professionalization','Term Limits','Citizen Init.','Elected Court','Interest Group Opposition','Turnout','One-Party Dominance'),stars=c(.05),dcolumn=T,label="congruenceLP",caption="\\textbf{Policy Congruence Models}",caption.above=T)

inst.data<-read.csv('inst_measures.csv')
inst.data <- subset(inst.data, year==2008)
inst.data$year <- NULL
inst.data$ostate.full <- inst.data$abbr
inst.data$abbr <- NULL
lp.data <- merge(lp.data,inst.data,by=c("ostate.full"))


### Change out institutions in the congruence model
lp.newmeasure_congr<-glmer(congruence~rescale.size.of.majority.+
                                  rescale.nyt.bypolicygroup.full.+
                                  conservative.opinion.majority+
                                  flip.EWM.against+flip.Berry.against
                                +flip.legislative.share.dem.mean.full
                                +flip.gov.control.mean.dem.full+
                                  med_response+med_3+
                                  flip.powerful.balance.against+
                                  rescale.turnout.full.+
                                  rescale.onepartyness.full.+
                                  (rescale.size.of.majority.|ostate.full)+
                                  (rescale.size.of.majority.|issue.full)
                                ,family=binomial(link='logit'),
                                data=lp.data)
lp.high <- lp.data
lp.high$med_response <- lp.high$upper_response
lp.high$med_3 <- lp.high$upper_3
lp.high$med_1 <- lp.high$upper_1
lp.high$med_2 <- lp.high$upper_2




lp.newmeasure_congrhigh<-glmer(congruence~rescale.size.of.majority.+
                             rescale.nyt.bypolicygroup.full.+
                             conservative.opinion.majority+
                             flip.EWM.against+flip.Berry.against
                           +flip.legislative.share.dem.mean.full
                           +flip.gov.control.mean.dem.full+
                             med_response+med_3+
                             flip.powerful.balance.against+
                             rescale.turnout.full.+
                             rescale.onepartyness.full.+
                             (rescale.size.of.majority.|ostate.full)+
                             (rescale.size.of.majority.|issue.full)
                           ,family=binomial(link='logit'),
                           data=lp.high)

lp.low <- lp.data
lp.low$med_response <- lp.high$lower_response
lp.low$med_3 <- lp.high$lower_3
lp.low$med_2 <- lp.high$lower_2
lp.low$med_1 <- lp.high$lower_1

lp.newmeasure_congrlow<-glmer(congruence~rescale.size.of.majority.+
                             rescale.nyt.bypolicygroup.full.+
                             conservative.opinion.majority+
                             flip.EWM.against+flip.Berry.against
                           +flip.legislative.share.dem.mean.full
                           +flip.gov.control.mean.dem.full+
                             med_response+med_3+
                             flip.powerful.balance.against+
                             rescale.turnout.full.+
                             rescale.onepartyness.full.+
                             (rescale.size.of.majority.|ostate.full)+
                             (rescale.size.of.majority.|issue.full)
                           ,family=binomial(link='logit'),
                           data=lp.data)

texreg(list(lp.newmeasure_congr, lp.newmeasure_congrhigh, lp.newmeasure_congrlow),custom.model.names=c('Median Institutional Estimates', '97.5% Estimates', '2.5% Estiamtes'),
       custom.coef.names=c('Intercept','Size of Opinion Majority','Salience',
                           'Conservative Opinion Majority','Voter Ideological
                           Opposition','Govt. Ideological Opposition',
                           'Legislative Partisan Opposition','Governor Partisan
                           Opposition','Responsiveness Pressure',
                           'Inter-Branch Conflict',
                           'Interest Group Opposition',
                           'Turnout','One-Party Dominance')
                            ,stars=c(.05),dcolumn=T,
                            label="congruenceLP",
                            caption="\\textbf{Policy Congruence Models}",caption.above=T)



### including dimensions 1 & 2 separately
lp.3dim.congr<-glmer(congruence~rescale.size.of.majority.+
                             rescale.nyt.bypolicygroup.full.+
                             conservative.opinion.majority+
                             flip.EWM.against+flip.Berry.against
                           +flip.legislative.share.dem.mean.full
                           +flip.gov.control.mean.dem.full+
                             med_1+med_2+med_3+
                             flip.powerful.balance.against+
                             rescale.turnout.full.+
                             rescale.onepartyness.full.+
                             (rescale.size.of.majority.|ostate.full)+
                             (rescale.size.of.majority.|issue.full)
                           ,family=binomial(link='logit'),
                           data=lp.data)

lp.3dim.conghigh <-glmer(congruence~rescale.size.of.majority.+
                       rescale.nyt.bypolicygroup.full.+
                       conservative.opinion.majority+
                       flip.EWM.against+flip.Berry.against
                     +flip.legislative.share.dem.mean.full
                     +flip.gov.control.mean.dem.full+
                       med_1+med_2+med_3+
                       flip.powerful.balance.against+
                       rescale.turnout.full.+
                       rescale.onepartyness.full.+
                       (rescale.size.of.majority.|ostate.full)+
                       (rescale.size.of.majority.|issue.full)
                     ,family=binomial(link='logit'),
                     data=lp.high)

lp.3dim.congrlow<-glmer(congruence~rescale.size.of.majority.+
                       rescale.nyt.bypolicygroup.full.+
                       conservative.opinion.majority+
                       flip.EWM.against+flip.Berry.against
                     +flip.legislative.share.dem.mean.full
                     +flip.gov.control.mean.dem.full+
                       med_1+med_2+med_3+
                       flip.powerful.balance.against+
                       rescale.turnout.full.+
                       rescale.onepartyness.full.+
                       (rescale.size.of.majority.|ostate.full)+
                       (rescale.size.of.majority.|issue.full)
                     ,family=binomial(link='logit'),
                     data=lp.low)


texreg(list(lp.3dim.congr, lp.3dim.conghigh, lp.3dim.congrlow),,custom.model.names=c('Median Institutional Estimates', '97.5% Estimates', '2.5% Estiamtes'),
       custom.coef.names=c('Intercept','Size of Opinion Majority','Salience',
                           'Conservative Opinion Majority','Voter Ideological
                           Opposition','Govt. Ideological Opposition',
                           'Legislative Partisan Opposition','Governor Partisan
                           Opposition','Dim-1Responsiveness Pressure',
                           'Dim-2 Responsiveness Pressure','Inter-Branch Conflict',
                           'Interest Group Opposition',
                           'Turnout','One-Party Dominance')
                            ,stars=c(.1),dcolumn=T,
                            label="congruenceLP",
                            caption="\\textbf{Policy Congruence Models}",caption.above=T)


