

/// modeling scores

use mkdata_with_scores1, clear
gen med_response= med_1+med_2
gen lower_response=lower_1+lower_2
gen upper_response=upper_1+upper_2
save mkdata_ssq, replace


use mkdata_ssq, clear

label variable std_pop "Population"
label variable dem_unified "Unified Dem"
label variable rep_unified "Unified GOP"
label variable std_inc "Income"
label variable ranneyL "Competition Index"
label variable pct_urban  "Percent Urban"
label variable perc_black "Percent Black"
label variable state "State"
label variable culture3 "Political Culture"
replace perc_black=perc_black*100
egen std_urban=std(pct_urban)
label variable std_urban "Percent Urban"
egen std_black=std(perc_black)
label variable std_black "Percent Black"
egen std_nonwhite=std(nonwhite)
label variable std_nonwhite "Percent Black"

rename culture3 culture
recode culture (1=1 "Moralistic") (2=2 "Individualistic") (3=3 "Traditionalistic"), gen(culture3)
label variable culture3 "Political Culture"
label variable med_response "Accountability Pressure"
label variable med_3 "Checks and Balances"

recode region (1=1 "South") (2/4=0 "Non-South"), gen(south)
xtset stateno year
sureg med_response l.dem_unified l.rep_unified  ///
l.ranneyL  l.std_black l.i.culture3  l.std_pop l.std_inc l.std_urban
estimates store m1
sureg med_2 l.dem_unified l.rep_unified ///
l.ranneyL  l.std_black l.i.culture3  l.std_pop l.std_inc l.std_urban 
estimates store m2
sureg med_3 l.dem_unified l.rep_unified  ///
l.ranneyL  l.std_black l.i.culture3  l.std_pop l.std_inc l.std_urban  
estimates store m3



esttab m1 m3 using dimensions.tex, b(3) compress ///
		se label replace cells(b(fmt(4) star) noommited ///
		se(par)) starlevels(* .01)  rename([adoption]_cons constant) ///
		varwidth(30) mlabels("Accountability Pressure" "Checks and Balances") collabels(, none) eqlabels(, none) ///
		interaction(X) nobaselevels 
		
coefplot (m1, label(Accountability Pressure))  (m3, label(Checks and Balances)), xline(0) ///
xtitle("Coefficient Estimate") rename(_cons = Constant)  drop(_cons *.census_reg *.stateno *.year 1bL.culture3) ///
title("") legend(cols(3))  coeflabels(L.dem_unified="Unified Dem" L.rep_unified="Unified GOP" L.ranneyL="Competition Index" ///
 L.std_nonwhite="Percent Non-White" 2L.culture3="Individualistic" 3L.culture3="Traditionalistic" L.std_pop = "Population" L.std_inc="Income" ///
 L.std_urban="Percent Urban") graphregion(color(white)) bgcolor(white) scheme(s1mono)
 graph save Graph "score_models.gph", replace
 graph export "score_models.pdf", as(pdf) replace

 /// trying the other way
 reg ranneyL l.med_response l.ranneyL std_pop l.std_inc  l.dem_unified l.rep_unified ///
 l.std_urban l.std_black   l.i.culture3 i.year 
estimates store m1

//// seemingly unrelated regression
sureg (med_response l.std_pop l.std_inc  l.dem_unified l.rep_unified ///
l.ranneyL l.std_urban l.std_black  l.i.culture3 i.year) ///
(med_3 l.std_pop l.std_inc  l.dem_unified l.rep_unified ///
l.ranneyL l.std_urban l.std_black  l.i.culture3 i.year), corr
estimates store sreg 

esttab sreg using sureg.tex, unstack b(3) compress ///
		se label replace cells(b(fmt(4) star) noommited ///
		se(par)) starlevels(* .05) drop(*.year) rename([adoption]_cons constant) ///
		varwidth(30) mlabels("Accountability Pressure" "Checks and Balances") collabels(, none) eqlabels(, none) ///
		interaction(X) nobaselevels 

 //// trying all 3
 sureg (med_1 l.std_pop l.std_inc  l.dem_unified l.rep_unified ///
l.ranneyL l.std_urban l.std_black  l.i.culture3 i.year) ///
(med_2 l.std_pop l.std_inc  l.dem_unified l.rep_unified ///
l.ranneyL l.std_urban l.std_black  l.i.culture3 i.year) ///
(med_3 l.std_pop l.std_inc  l.dem_unified l.rep_unified ///
l.ranneyL l.std_urban l.std_black  l.i.culture3 i.year), corr
estimates store sreg1 

esttab sreg1, unstack b(3) compress ///
		se label replace cells(b(fmt(4) star) noommited ///
		se(par)) starlevels(* .1) drop(*.year) rename([adoption]_cons constant) ///
		varwidth(30) mlabels("Accountability Pressure" "Checks and Balances") collabels(, none) eqlabels(, none) ///
		interaction(X) nobaselevels 

 coefplot sreg, ///
 xtitle("Coefficient Estimate") rename(_cons = Constant)  drop(*.year) xline(0)


